<?php

namespace Drupal\cas_server\Ticket;

/**
 * Ticket provided to user client on successful authentication.
 */
class ServiceTicket extends Ticket {

  /**
   * The service this ticket was granted for.
   *
   * @var string
   */
  protected $service;

  /**
   * The renew parameter flag for this ticket.
   *
   * Whether or not this ticket was created by presentation of credentials,
   * rather than a single sign-on session. For use with 'renew' parameter.
   *
   * @var bool
   */
  protected $renew;

  /**
   * Constructs a new ServiceTicket object.
   *
   * @param string $identifier
   *   The data used to identify the ticket.
   * @param string $expiry
   *   A unix timestamp describing the expiration time.
   * @param string $session_string
   *   The hashed session ID of the requestor of ticket.
   * @param string $uid
   *   The uid of the requestor.
   * @param string $username
   *   The username of the requestor.
   * @param string $service_string
   *   URL of the service the ticket is to be used for.
   * @param bool $creds_supplied
   *   Whether or not this ticket was generated by directly supplying creds.
   */
  public function __construct(
    $identifier,
    $expiry,
    $session_string,
    $uid,
    $username,
    $service_string,
    $creds_supplied,
  ) {
    $this->id = $identifier;
    $this->expirationTime = $expiry;
    $this->session = $session_string;
    $this->uid = $uid;
    $this->user = $username;
    $this->service = $service_string;
    $this->renew = $creds_supplied;
  }

  /**
   * Return the service the ticket is valid for.
   *
   * @return string
   *   The service string.
   */
  public function getService() {
    return $this->service;
  }

  /**
   * Get the contents of the renew flag for this ticket.
   *
   * @return bool
   *   The renew parameter.
   */
  public function getRenew() {
    return $this->renew;
  }

}
